#!/usr/bin/env node
'use strict';

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _postcss = require('postcss');

var _postcss2 = _interopRequireDefault(_postcss);

var _defaultConfig = require('../defaultConfig');

var _defaultConfig2 = _interopRequireDefault(_defaultConfig);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _2 = require('..');

var _3 = _interopRequireDefault(_2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function loadConfig(configPath) {
  if (configPath === undefined) {
    return undefined;
  }

  if (!_fsExtra2.default.existsSync(_path2.default.resolve(configPath))) {
    console.error(`Config file [${configPath}] does not exist.`);
    process.exit(1);
  }

  return require(_path2.default.resolve(configPath));
}

function writeStrategy(program) {
  if (program.output === undefined) {
    return output => {
      process.stdout.write(output);
    };
  }
  return output => {
    _fsExtra2.default.outputFileSync(program.output, output);
  };
}

function buildTailwind(inputFile, config, write) {
  console.log('Building Tailwind!');

  const input = _fsExtra2.default.readFileSync(inputFile, 'utf8');

  return (0, _postcss2.default)([(0, _3.default)(config)]).process(input).then(result => {
    write(result.css);
    console.log('Finished building Tailwind!');
  }).catch(error => console.log(error));
}

_commander2.default.version('0.1.0').usage('<command> [<args>]');

_commander2.default.command('init [filename]').usage('[options] [filename]').action(function (filename = 'tailwind.js') {
  const destination = _path2.default.resolve(filename);

  if (_fsExtra2.default.existsSync(destination)) {
    console.log(`Destination ${destination} already exists, aborting.`);
    process.exit(1);
  }

  const output = _fsExtra2.default.readFileSync(_path2.default.resolve(__dirname + '/../defaultConfig.js'), 'utf8');
  _fsExtra2.default.outputFileSync(destination, output.replace('// var defaultConfig', 'var defaultConfig'));
  process.exit();
});

_commander2.default.command('build').usage('[options] <file ...>').option('-c, --config [path]', 'Path to config file').option('-o, --output [path]', 'Output file').action(function () {
  let inputFile = _commander2.default.args[0];

  if (!inputFile) {
    console.error('No input file given!');
    process.exit(1);
  }

  buildTailwind(inputFile, loadConfig(_commander2.default.config), writeStrategy(_commander2.default)).then(function () {
    process.exit();
  });
});

_commander2.default.command('*').action(function () {
  _commander2.default.help();
});

_commander2.default.parse(process.argv);

if (_commander2.default.args.length === 0) {
  _commander2.default.help();
  process.exit();
}