'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _postcss = require('postcss');

var _postcss2 = _interopRequireDefault(_postcss);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _findMixin = require('../util/findMixin');

var _findMixin2 = _interopRequireDefault(_findMixin);

var _escapeClassName = require('../util/escapeClassName');

var _escapeClassName2 = _interopRequireDefault(_escapeClassName);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function normalizeClassNames(classNames) {
  return classNames.map(className => {
    return `.${(0, _escapeClassName2.default)(_lodash2.default.trimStart(className, '.'))}`;
  });
}

exports.default = _postcss2.default.plugin('tailwind-apply', function (css) {
  return function (css) {
    css.walkRules(function (rule) {
      rule.walkAtRules('apply', atRule => {
        const mixins = normalizeClassNames(_postcss2.default.list.space(atRule.params));

        /*
         * Don't wreck CSSNext-style @apply rules:
         * http://cssnext.io/features/#custom-properties-set-apply
         *
         * These are deprecated in CSSNext but still playing it safe for now.
         * We might consider renaming this at-rule.
         */
        const [customProperties, classes] = _lodash2.default.partition(mixins, mixin => {
          return _lodash2.default.startsWith(mixin, '--');
        });

        const decls = _lodash2.default.flatMap(classes, mixin => {
          return (0, _findMixin2.default)(css, mixin, () => {
            throw atRule.error(`No ${mixin} class found.`);
          });
        });

        atRule.before(decls);

        atRule.params = customProperties.join(' ');

        if (_lodash2.default.isEmpty(customProperties)) {
          atRule.remove();
        }
      });
    });
  };
});